"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AsyncStorageAssignmentShim = void 0;
var _asyncStorage = _interopRequireDefault(require("@react-native-async-storage/async-storage"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
class AsyncStorageAssignmentShim {
  constructor(storageKeySuffix) {
    const keySuffix = storageKeySuffix ? `-${storageKeySuffix}` : '';
    this.storageKey = `eppo-assignment${keySuffix}`;
    this.cache = new Map();
    this.initCache();
  }
  async initCache() {
    const stored = await _asyncStorage.default.getItem(this.storageKey);
    this.cache = stored ? new Map(JSON.parse(stored)) : new Map();
  }
  async persistCache() {
    await _asyncStorage.default.setItem(this.storageKey, JSON.stringify(Array.from(this.cache.entries())));
  }
  clear() {
    this.cache.clear();
    _asyncStorage.default.removeItem(this.storageKey).catch(console.error);
  }
  delete(key) {
    const result = this.cache.delete(key);
    this.persistCache().catch(console.error);
    return result;
  }
  forEach(callbackfn, thisArg) {
    this.cache.forEach(callbackfn, thisArg);
  }
  get size() {
    return this.cache.size;
  }
  entries() {
    return this.cache.entries();
  }
  keys() {
    return this.cache.keys();
  }
  values() {
    return this.cache.values();
  }
  [Symbol.iterator]() {
    return this.cache[Symbol.iterator]();
  }
  get [Symbol.toStringTag]() {
    return this.cache[Symbol.toStringTag];
  }
  has(key) {
    return this.cache.has(key);
  }
  get(key) {
    return this.cache.get(key);
  }
  set(key, value) {
    this.cache.set(key, value);
    this.persistCache().catch(console.error);
    return this;
  }
}
exports.AsyncStorageAssignmentShim = AsyncStorageAssignmentShim;
//# sourceMappingURL=async-storage-assignment-shim.js.map