"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "AttributeType", {
  enumerable: true,
  get: function () {
    return _jsClientSdkCommon.AttributeType;
  }
});
Object.defineProperty(exports, "Attributes", {
  enumerable: true,
  get: function () {
    return _jsClientSdkCommon.Attributes;
  }
});
Object.defineProperty(exports, "BanditActions", {
  enumerable: true,
  get: function () {
    return _jsClientSdkCommon.BanditActions;
  }
});
Object.defineProperty(exports, "BanditSubjectAttributes", {
  enumerable: true,
  get: function () {
    return _jsClientSdkCommon.BanditSubjectAttributes;
  }
});
Object.defineProperty(exports, "ContextAttributes", {
  enumerable: true,
  get: function () {
    return _jsClientSdkCommon.ContextAttributes;
  }
});
Object.defineProperty(exports, "EppoClient", {
  enumerable: true,
  get: function () {
    return _jsClientSdkCommon.EppoClient;
  }
});
exports.EppoReactNativeClient = exports.EppoPrecomputedReactNativeClient = void 0;
Object.defineProperty(exports, "IAssignmentDetails", {
  enumerable: true,
  get: function () {
    return _jsClientSdkCommon.IAssignmentDetails;
  }
});
Object.defineProperty(exports, "IAssignmentEvent", {
  enumerable: true,
  get: function () {
    return _jsClientSdkCommon.IAssignmentEvent;
  }
});
Object.defineProperty(exports, "IAssignmentLogger", {
  enumerable: true,
  get: function () {
    return _jsClientSdkCommon.IAssignmentLogger;
  }
});
Object.defineProperty(exports, "IBanditEvent", {
  enumerable: true,
  get: function () {
    return _jsClientSdkCommon.IBanditEvent;
  }
});
Object.defineProperty(exports, "IBanditLogger", {
  enumerable: true,
  get: function () {
    return _jsClientSdkCommon.IBanditLogger;
  }
});
exports.getInstance = getInstance;
exports.getPrecomputedInstance = getPrecomputedInstance;
exports.init = init;
exports.precomputedInit = precomputedInit;
var _jsClientSdkCommon = require("@eppo/js-client-sdk-common");
var _asyncStorage = require("./async-storage");
var _sdkData = require("./sdk-data");
var _assignmentCacheFactory = require("./cache/assignment-cache-factory");
var _hybridAssignmentCache = _interopRequireDefault(require("./cache/hybrid-assignment-cache"));
var _sparkMd = _interopRequireDefault(require("spark-md5"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const asyncStorage = new _asyncStorage.EppoAsyncStorage();
const memoryOnlyPrecomputedFlagsStore = new _jsClientSdkCommon.MemoryOnlyConfigurationStore();
const memoryOnlyPrecomputedBanditsStore = new _jsClientSdkCommon.MemoryOnlyConfigurationStore();

/**
 * Builds a storage key suffix from an API key.
 * @param apiKey - The API key to build the suffix from
 * @returns A string suffix for storage keys
 */
function buildStorageKeySuffix(apiKey) {
  // Note that we use the first 8 characters of the hashed API key to create per-API key persistent storages and caches
  const hashedApiKey = new _sparkMd.default().append(apiKey).end();
  return hashedApiKey.substring(0, 8);
}
class EppoReactNativeClient extends _jsClientSdkCommon.EppoClient {
  static initialized = false;
  static instance = new EppoReactNativeClient({
    flagConfigurationStore: asyncStorage
  });
}

/**
 * Initializes the Eppo client with configuration parameters.
 * This method should be called once on application startup.
 * @param config client configuration
 * @public
 */
exports.EppoReactNativeClient = EppoReactNativeClient;
async function init(config) {
  _jsClientSdkCommon.validation.validateNotBlank(config.apiKey, 'API key required');
  try {
    // If any existing instances; ensure they are not polling
    if (EppoReactNativeClient.instance) {
      EppoReactNativeClient.instance.stopPolling();
    }
    const requestConfiguration = {
      apiKey: config.apiKey,
      sdkName: _sdkData.sdkName,
      sdkVersion: _sdkData.sdkVersion,
      baseUrl: config.baseUrl ?? undefined,
      requestTimeoutMs: config.requestTimeoutMs ?? undefined,
      numInitialRequestRetries: config.numInitialRequestRetries ?? undefined,
      numPollRequestRetries: config.numPollRequestRetries ?? undefined,
      throwOnFailedInitialization: true,
      // always use true here as underlying instance fetch is surrounded by try/catch
      pollAfterSuccessfulInitialization: config.pollAfterSuccessfulInitialization ?? false,
      pollAfterFailedInitialization: config.pollAfterFailedInitialization ?? false,
      pollingIntervalMs: config.pollingIntervalMs ?? undefined
    };
    EppoReactNativeClient.instance.setAssignmentLogger(config.assignmentLogger);
    const storageKeySuffix = buildStorageKeySuffix(config.apiKey);
    const assignmentCache = (0, _assignmentCacheFactory.assignmentCacheFactory)({
      storageKeySuffix
    });
    if (assignmentCache instanceof _hybridAssignmentCache.default) {
      await assignmentCache.init();
    }
    EppoReactNativeClient.instance.useCustomAssignmentCache(assignmentCache);
    EppoReactNativeClient.instance.setConfigurationRequestParameters(requestConfiguration);
    await asyncStorage.init();
    await EppoReactNativeClient.instance.fetchFlagConfigurations();
    EppoReactNativeClient.initialized = true;
    return EppoReactNativeClient.instance;
  } catch (error) {
    console.warn('Eppo SDK encountered an error initializing, assignment calls will return the default value and not be logged.');
    if (config.throwOnFailedInitialization ?? true) {
      throw error;
    }
    return EppoReactNativeClient.instance;
  }
}

/**
 * Used to access a singleton SDK client instance.
 * Use the method after calling init() to initialize the client.
 * @returns a singleton client instance
 */
function getInstance() {
  return EppoReactNativeClient.instance;
}
class EppoPrecomputedReactNativeClient extends _jsClientSdkCommon.EppoPrecomputedClient {
  static initialized = false;
  static instance = new EppoPrecomputedReactNativeClient({
    precomputedFlagStore: memoryOnlyPrecomputedFlagsStore,
    subject: {
      subjectKey: '',
      subjectAttributes: {}
    }
  });
}

/**
 * Initializes the Eppo precomputed client with configuration parameters.
 * This method should be called once on application startup.
 * @param config - client configuration
 * @public
 */
exports.EppoPrecomputedReactNativeClient = EppoPrecomputedReactNativeClient;
async function precomputedInit(config) {
  if (EppoPrecomputedReactNativeClient.initialized) {
    return EppoPrecomputedReactNativeClient.instance;
  }
  _jsClientSdkCommon.validation.validateNotBlank(config.apiKey, 'API key required');
  _jsClientSdkCommon.validation.validateNotBlank(config.precompute.subjectKey, 'Subject key required');
  const {
    apiKey,
    precompute: {
      subjectKey,
      subjectAttributes = {},
      banditActions
    },
    baseUrl,
    requestTimeoutMs,
    numInitialRequestRetries,
    numPollRequestRetries,
    pollingIntervalMs,
    pollAfterSuccessfulInitialization = false,
    pollAfterFailedInitialization = false,
    skipInitialRequest = false
  } = config;
  const storageKeySuffix = buildStorageKeySuffix(config.apiKey);
  const assignmentCache = (0, _assignmentCacheFactory.assignmentCacheFactory)({
    storageKeySuffix
  });
  if (assignmentCache instanceof _hybridAssignmentCache.default) {
    await assignmentCache.init();
  }
  EppoReactNativeClient.instance.useCustomAssignmentCache(assignmentCache);

  // Set up parameters for requesting updated configurations
  const requestParameters = {
    apiKey,
    sdkName: _sdkData.sdkName,
    sdkVersion: _sdkData.sdkVersion,
    baseUrl,
    requestTimeoutMs,
    numInitialRequestRetries,
    numPollRequestRetries,
    pollAfterSuccessfulInitialization,
    pollAfterFailedInitialization,
    pollingIntervalMs,
    throwOnFailedInitialization: true,
    // always use true here as underlying instance fetch is surrounded by try/catch
    skipInitialPoll: skipInitialRequest
  };
  const subject = {
    subjectKey,
    subjectAttributes
  };
  EppoPrecomputedReactNativeClient.instance = new EppoPrecomputedReactNativeClient({
    precomputedFlagStore: memoryOnlyPrecomputedFlagsStore,
    requestParameters,
    subject,
    precomputedBanditStore: memoryOnlyPrecomputedBanditsStore,
    banditActions
  });
  EppoPrecomputedReactNativeClient.instance.setAssignmentLogger(config.assignmentLogger);
  if (config.banditLogger) {
    EppoPrecomputedReactNativeClient.instance.setBanditLogger(config.banditLogger);
  }
  await EppoPrecomputedReactNativeClient.instance.fetchPrecomputedFlags();
  EppoPrecomputedReactNativeClient.initialized = true;
  return EppoPrecomputedReactNativeClient.instance;
}

/**
 * Used to access a singleton SDK precomputed client instance.
 * Use the method after calling precomputedInit() to initialize the client.
 * @returns a singleton precomputed client instance
 * @public
 */
function getPrecomputedInstance() {
  return EppoPrecomputedReactNativeClient.instance;
}
//# sourceMappingURL=index.js.map