import { FormatEnum } from '@eppo/js-client-sdk-common';
import AsyncStorage from '@react-native-async-storage/async-storage';

// Bump this version number when we make breaking changes to the cache.
export const STORAGE_KEY = '@eppo/sdk-cache-ufc';
class AsyncStorageStore {
  cache = {};
  _isInitialized = false;
  async init() {
    const data = await AsyncStorage.getItem(STORAGE_KEY);
    if (data !== null) {
      this.cache = JSON.parse(data);
    }
  }
  isInitialized() {
    return this._isInitialized;
  }
  get(key) {
    return this.cache[key];
  }
  getKeys() {
    return Object.keys(this.cache);
  }
  entries() {
    return this.cache;
  }
  setEntries(entries) {
    for (var key in entries) {
      this.cache[key] = entries[key];
    }
    AsyncStorage.setItem(STORAGE_KEY, JSON.stringify(this.cache));
    this._isInitialized = true;
  }
}
export class EppoAsyncStorage {
  environment = null;
  configFetchedAt = null;
  configPublishedAt = null;
  format = null;
  constructor() {
    this.servingStore = new AsyncStorageStore();
    this.persistentStore = null;
    this.initialized = false;
    this.configFetchedAt = '';
    this.configPublishedAt = '';
    this.format = FormatEnum.CLIENT;
  }
  init() {
    this.initialized = true;
    return Promise.resolve();
  }
  get(key) {
    return this.servingStore.get(key);
  }
  getKeys() {
    return this.servingStore.getKeys();
  }
  async isExpired() {
    return true;
  }
  isInitialized() {
    return this.initialized;
  }
  entries() {
    return this.servingStore.entries();
  }
  async setEntries(entries) {
    this.servingStore.setEntries(entries);
    this.initialized = true;
    return true;
  }
  getEnvironment() {
    return this.environment;
  }
  setEnvironment(environment) {
    this.environment = environment;
  }
  getConfigFetchedAt() {
    return this.configFetchedAt;
  }
  setConfigFetchedAt(configFetchedAt) {
    this.configFetchedAt = configFetchedAt;
  }
  getConfigPublishedAt() {
    return this.configPublishedAt;
  }
  setConfigPublishedAt(configPublishedAt) {
    this.configPublishedAt = configPublishedAt;
  }
  getFormat() {
    return this.format;
  }
  setFormat(format) {
    this.format = format;
  }
}
//# sourceMappingURL=async-storage.js.map